@@ -5,14 +5,14 @@ import urllib.request
 
 def test_extract_ip():
     # set_trace()
-    test_html='\t\t\t\t<span style="font-size: 1.4em">Your current IP-Adress: <font color="#FFFF33">110.168.32.26</font><br> \t\t\t\t\t\t\t\t<br>'
+    test_html=b'\t\t\t\t<span style="font-size: 1.4em">Your current IP-Adress: <font color="#FFFF33">110.168.32.26</font><br> \t\t\t\t\t\t\t\t<br>'
     ip = extract_ip(test_html)
     assert ip == "110.168.32.26"
 
 def extract_ip(html):
 # setup_version_pattern = r"(\w+=')(\d+.\d+.)(\d+)('.*)"
     ip_addy_regex = r"Your current IP-Adress:.*>(\d+\.\d+\.\d+\.\d+)"
-    matches = re.search(ip_addy_regex, html)
+    matches = re.search(ip_addy_regex, html.decode("utf-8"))
     ip = matches.group(1)
     return ip
 
